@@ -84,18 +84,18 @@ gboolean darksnow_config_store(char opt, char *save_path) {
   adddate = (char) (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (checkbutton_adddate) ))? '1': '0';
   
   /* Combo box inputs */
-  icecast = (char *) gtk_entry_get_text ( GTK_ENTRY( GTK_COMBO(combo_icecast)->entry));
-  format = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO (combo_format)->entry ));
-  bitrate = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_bitrate)->entry));
-  bitratemode = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_bitratemode)->entry));
-  samplerate = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_samplerate)->entry));
-  quality = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_quality)->entry));
-  bitspersample = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_bitspersample)->entry));
-  channel = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_channel)->entry));
-  buffersize = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_buffersize)->entry));
-  device = (char *) gtk_entry_get_text ( GTK_ENTRY(GTK_COMBO(combo_device)->entry));
-  public = (char *) gtk_entry_get_text  ( GTK_ENTRY(GTK_COMBO(combo_public)->entry));
-  verbosity = (char *) gtk_entry_get_text  ( GTK_ENTRY(GTK_COMBO(combo_verbosity)->entry));
+  icecast = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_icecast));
+  format = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_format));
+  bitrate = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_bitrate));
+  bitratemode = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_bitratemode));
+  samplerate = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_samplerate));
+  quality = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_quality));
+  bitspersample = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_bitspersample));
+  channel = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_channel));
+  buffersize = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_buffersize));
+  device = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_device));
+  public = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_public));
+  verbosity = gtk_combo_box_text_get_active_text  ( GTK_COMBO_BOX_TEXT(combo_verbosity));
   
 
   if (!( f_darksnow_cfg = (opt != 0)? fopen(darksnow_cfg, "w") : fopen(save_path, "w"))) {
@@ -226,7 +226,10 @@ gboolean darksnow2darkice_cfg() {
   fprintf(f_darkice_cfg, "%s", buffersize);        /* size of internal slip buffer, in seconds */
   fprintf(f_darkice_cfg, "\n\n[input]");
   fprintf(f_darkice_cfg, "\ndevice = ");
-  fprintf(f_darkice_cfg, "%s", device); /* OSS, ALSA or JACK */
+  fprintf(f_darkice_cfg, "%s", device); /* OSS, ALSA, Pulse or JACK */
+  if (!strcmp(device, "pulseaudio")) {
+      fprintf(f_darkice_cfg, "\npaSourceName = default");
+  }
   fprintf(f_darkice_cfg, "\nsampleRate = "); 
   fprintf(f_darkice_cfg, "%s", samplerate); /* sample rate in Hz. try 11025, 22050 or 44100 */
   fprintf(f_darkice_cfg, "\nbitsPerSample = ");
@@ -256,13 +259,13 @@ gboolean darksnow2darkice_cfg() {
 
   /* write bitratemode */
   fprintf(f_darkice_cfg, "\nbitrateMode = ");
-  if (!strcmp( gettext("Constant"), bitratemode))
+  if (!strcmp(gettext("Constant"), bitratemode))
     fprintf(f_darkice_cfg, "cbr"); /* Constant bitrate mode */
   else 
-    if (!strcmp( gettext("Average"), bitratemode))
+    if (!strcmp(gettext("Average"), bitratemode))
       fprintf(f_darkice_cfg, "abr"); /* average bitrate mode */
-    else 
-      if (!strcmp( gettext("Variable"), bitratemode)) 
+  else 
+    if (!strcmp(gettext("Variable"), bitratemode)) 
       fprintf(f_darkice_cfg, "vbr"); /* variable bitrate mode */
   
 
@@ -273,10 +276,14 @@ gboolean darksnow2darkice_cfg() {
       fprintf(f_darkice_cfg, "mp3"); 
     else if (!strcmp( gettext("ogg/vorbis"), format))
       fprintf(f_darkice_cfg, "vorbis"); 
+    else if (!strcmp( gettext("ogg/opus"), format))
+      fprintf(f_darkice_cfg, "opus"); 
     else if (!strcmp( gettext("aac"), format))
       fprintf(f_darkice_cfg, "aac");
     else if (!strcmp( gettext("mp2"), format))
       fprintf(f_darkice_cfg, "mp2");
+    else if (!strcmp( gettext("aacp"), format))
+      fprintf(f_darkice_cfg, "aacp");
   }
   
   fprintf(f_darkice_cfg, "\nbitrate = ");
